unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls;

const _MAX_PATH=256;

type
  //define library function interface
  TFunc_DecryptPDF = function(inFileName: PChar;outFileName: PChar;
                              OwnerPassword: PChar;UserPassword: PChar;
                              keywords: PChar;subject: PChar;
                              title: PChar;author: PChar;
                              creator: PChar):Longint; stdcall;
  TFunc_IsEncryptPDF = function(inFileName: PChar):boolean; stdcall;
  TFunc_IsPDFFormat = function(inFileName: PChar):boolean; stdcall;

  TMainForm = class(TForm)
    btnDemo: TButton;
    procedure btnDemoClick(Sender: TObject);
  private
    { Private declarations }
    Handle: THandle;
    _DecryptPDF: TFunc_DecryptPDF;
    _IsEncryptPDF: TFunc_IsEncryptPDF;
    _IsPDFFormat: TFunc_IsPDFFormat;

    function GetModulePath(in_name: String):String;
    function LoadDecryptPDF():boolean;
    function FreeDecryptPDF():boolean;
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.dfm}

function TMainForm.GetModulePath(in_name: String):String;
var
    out_path: String;
begin
    SetLength(out_path,_MAX_PATH);
    GetModuleFileName(0,PChar(out_path),_MAX_PATH);
    out_path := trim(out_path);
    //SetLength(out_path,Length(out_path));

    out_path := Copy(out_path,0,Pos(StrPas(StrRScan(PChar(out_path),'\')), out_path));
    out_path := out_path+in_name;
    Result:=out_path;
end;

//load pdf decrypt library
function TMainForm.LoadDecryptPDF():boolean;
var
    path: String;
begin
    path := GetModulePath('apPDFPasswordRecovery.dll');
    Handle := LoadLibrary(PChar(path));
    if( Handle <> 0 )then
    begin
        @_DecryptPDF := GetProcAddress(Handle, '_DecryptPDF@36');
        if( @_DecryptPDF = nil )then
        begin
            FreeDecryptPDF();
            Result := false;
            exit;
        end;

        @_IsEncryptPDF := GetProcAddress(Handle, '_IsEncryptPDF@4');
        if( @_IsEncryptPDF = nil )then
        begin
            FreeDecryptPDF();
            Result := false;
            exit;
        end;

        @_IsPDFFormat := GetProcAddress(Handle, '_IsPDFFormat@4');
        if( @_IsPDFFormat = nil )then
        begin
            FreeDecryptPDF();
            Result := false;
            exit;
        end;

        Result := true;
    end else begin
        Result := false;
    end;
end;

//free pdf decrypt library
function TMainForm.FreeDecryptPDF():boolean;
begin
    if( Handle <> 0 )then
        FreeLibrary(Handle);
    Result := true;
end;

//demo
procedure TMainForm.btnDemoClick(Sender: TObject);
var
    srcpath: array[0..255]of char;
    despath: array[0..255]of char;
    lRet: Longint;
begin
    //load library
    if( LoadDecryptPDF() = false)then
    begin
        ShowMessage('load dll failure...');
        exit;
    end;

    //......
    StrPCopy(srcpath,GetModulePath('encrypt1.pdf'));
    if( _IsPDFFormat(srcpath) ) then
    begin
        if( _IsEncryptPDF(srcpath) )then
        begin
            StrPCopy(despath,GetModulePath('decrypt_owner.pdf'));
            _DecryptPDF(srcpath,despath,'owner',nil,'keywords','subject','title','author','creator');

            StrPCopy(despath,GetModulePath('decrypt_user.pdf'));
            _DecryptPDF(srcpath,despath,nil,'user',nil,nil,nil,nil,nil);

            showmessage('Decryption successful!');
        end else begin
            showmessage('This isn''t Decryption pdf file.');
        end;

        StrPCopy(srcpath,GetModulePath('encrypt2.pdf'));
        StrPCopy(despath,GetModulePath('decrypt2.pdf'));
        _DecryptPDF(srcpath,despath,nil,nil,nil,nil,nil,nil,nil);
    end else begin
        showmessage('This isn''t pdf file.');
    end;

    //free library
    FreeDecryptPDF();
end;

end.
